#include <stdio.h>

#include <algorithm>
#include <iostream>
#include <string>
#include <vector>

#include <boost/format.hpp>

#include <private/shared/AutoLocker.h>
#include <Directory.h>
#include <File.h>

void lock_and_populate(std::string const & dirname, std::vector<std::string> const & files)
{
	auto dir = BDirectory{dirname.c_str()};
	auto ret = dir.InitCheck();
	if(B_OK != ret)
		throw (boost::format("BDirectory::InitCheck: %s: %s")
			% dirname % strerror(ret)).str();

	ret = dir.Lock();
	if(B_OK != ret)
		throw (boost::format("Locking: %s: %s")
			% dirname % strerror(ret)).str();

	std::ranges::for_each(files, [&dir](std::string const & f) {
		dir.CreateFile(f.c_str(), 0);
	});
}

int main(int argc, char *argv[])
{
	if(argc < 2)
		return 1;

	auto dir = std::string{argv[1]};

	auto tracker_command = (boost::format("/boot/system/Tracker %s")  % dir.c_str()).str();
	auto tracker = popen(tracker_command.c_str(), "r");
	if(NULL == tracker)
		throw (boost::format("Failed launching Tracker: %s: %s")
			% dir % strerror(errno)).str();
	pclose(tracker);

	{
		// Wait for the Tracker app to exec, read and wait
		// 1 second doesn't let enough time on my system, you might need to adjust to a
		// higher value to observe the bug
		sleep(2);
	}

	auto files = std::vector<std::string>{argv+2, argv+argc};
	try
	{
		lock_and_populate(dir, files);
	}
	catch(std::string const & e)
	{
		std::cerr << e << std::endl;
	}

	return 0;
}
